import React, { useState, useEffect } from 'react';
import { dispatch } from '../../../../domain/gameStore';
import ClickMarkerMap from './ClickMarkerMap';
import styles from './GuessPane.module.css';
import RoundTimer from './RoundTimer';

export default () => {
  const [ selectedPoint, setSelectedPoint ] = useState(null);
  const [ submitted, setSubmitted ] = useState(false);
  const [ bigMap, setBigMap ] = useState(false);

  useEffect(() => {
    const listener = event => {
      if (event.code === 'Escape') {
        setBigMap(b => !b);
      }
    }
    document.addEventListener("keydown", listener, false);
    return () => document.removeEventListener("keydown", listener, false);

  }, [])

  const handleSubmitGuess = async () => {
    setSubmitted(true);
    if (!submitted) {
      await dispatch.submitGuess(selectedPoint);
    }
  };

  return (
    <div className={`${styles.pane} ${bigMap ? styles['pane--big'] : styles['pane--small']}`}>
      <button
        className={styles.submit}
        onClick={handleSubmitGuess}
        disabled={submitted || selectedPoint === null}
      >
        Submit Guess
      </button>
      <ClickMarkerMap onMarkerMoved={setSelectedPoint} />
      <RoundTimer onTimeout={handleSubmitGuess} />
      <div className={styles.resize} onClick={() => setBigMap(b => !b)}>
        {bigMap ? '↙️' : '↗️'}
      </div>
    </div>
  );
};
